pub struct Machine {
pub id: String,
pub image: Option<String>,
pub version: String,
pub memory: Option<usize>,
}Expand description
Information about the Fly.io Machine on which the current process is running.
Fields
id: StringThe unique ID of this Fly.io Machine.
Fly.io exposes this value to VM’s as $FLY_MACHINE_ID.
image: Option<String>The name of the Docker image running this container.
Fly.io exposes this value to VM’s as $FLY_IMAGE_REF.
version: StringThe version assigned to a specific Fly.io Machine configuration.
Fly.io exposes this value to VM’s as $FLY_MACHINE_VERSION.
memory: Option<usize>The memory allocated to the Fly.io Machine, in MB.
Fly.io exposes this value to VM’s as $FLY_VM_MEMORY_MB.
Implementations